@@ -176,6 +176,7 @@ extern const long VERYBIGINT;        /* 2^31-1               */
 extern  char    *helpmessage[]; /* un message pour chaque fonction predefinie */
 extern  char    *errmessage[];  /* un par numero d'erreur */
 extern  char    *pariversion;
+/*#define HAVEEXP2*/
 #ifdef HAVEEXP2
 #ifdef __cplusplus
 extern "C" {
@@ -189,7 +190,7 @@ inline double exp2(double x) {return exp(x*LOG2);}
 inline double log2(double x) {return log(x)/LOG2;}
 #else
 #define exp2(x) exp((double)(x)*LOG2)
-#define log2(x) log((double)(x)/LOG2)
+#define log2(x) log((double)(x))/LOG2
 #endif
 #endif
 
